# -*- coding: utf-8 -*-
ISBNs = r"""
ISBN 9781849284677
qwe iuwer 9780312640583 kjhfds
bh bh isbn 978-0312640583
bh bh isbn 978 031264058 3
bh bh isbn978 031264058 3
ISBN 0-330-28498-3 jhjhISBN 1-58182-008-9
ISBN 2-226-05257-7
ISBN 3-7965-1900-8
ISBN 4-19-830127-1
ISBN 5-85270-001-0
ISBN 978-600-119-125-1
ISBN 978-601-7151-13-3
ISBN 978-602-8328-22-7
ISBN 978-603-500-045-1
ISBN 605-384-057-2
ISBN 978-606-8126-35-7
ISBN 978-607-455-035-1
ISBN 978-608-203-023-4
ISBN 978-612-45165-9-7
ISBN 978-614-404-018-8
ISBN 978-615-5014-99-4
ISBN 7-301-10299-2
ISBN 80-85983-44-3
ISBN 81-7215-399-6
ISBN 82-530-0983-6
ISBN 83-08-01587-5
ISBN 84-86546-08-7
ISBN 85-7531-015-1
ISBN 86-341-0846-5
ISBN 87-595-2277-1
ISBN 88-04-47328-2
ISBN 90-5691-187-2
ISBN 91-1-811692-2
ISBN 92-67-10370-9
ISBN 93-8011-236-7
ISBN 94-414-0063-3
ISBN 950-04-0442-7
ISBN 951-0-11369-7
ISBN 952-471-294-6
ISBN 953-157-105-8
ISBN 954-430-603-X
ISBN 955-20-3051-X
ISBN 956-7291-48-9
ISBN 957-01-7429-3
ISBN 958-04-6278-X
ISBN 959-10-0363-3
ISBN 961-6403-23-0
ISBN 962-04-0195-6
ISBN 963-7971-51-3
ISBN 964-6194-70-2
ISBN 965-359-002-2
ISBN 966-95440-5-X
ISBN 967-978-753-2
ISBN 968-6031-02-2
ISBN 969-031-02-2
ISBN 970-20-0242-7
ISBN 971-8845-10-0
ISBN 972-37-0274-6
ISBN 973-43-0179-9
ISBN 974-85854-7-6
ISBN 975-293-381-5
ISBN 976-640-140-3
ISBN 977-734-520-8
ISBN 978-37186-2-2
ISBN 979-553-483-1
ISBN 980-01-0194-2
ISBN 981-3018-39-9
ISBN 982-301-001-3
ISBN 983-52-0157-9
ISBN 984-458-089-7
ISBN 986-417-191-7
ISBN 987-98184-2-3
ISBN 978-988-00-3827-3
ISBN 978-9928400529
ISBN 978-9929801646
ISBN 978-9930943106
ISBN 978-9933101473
ISBN 978-9934015960
ISBN 978-99937-1-056-1
ISBN 978-99965-2-047-1
"""

# flake8: noqa
